@@ -73,6 +73,20 @@ task_data_new (GtdProviderEds *provider,
   return tdata;
 }
 
+static void
+gtd_provider_eds_set_default (GtdProviderEds *self,
+                              GtdTaskList    *list)
+{
+  GtdProviderEdsPrivate *priv;
+  ESource *source;
+
+  priv = gtd_provider_eds_get_instance_private (self);
+  source = gtd_task_list_eds_get_source (GTD_TASK_LIST_EDS (list));
+
+  gtd_manager_set_default_provider (gtd_manager_get_default (), GTD_PROVIDER (self));
+  e_source_registry_set_default_task_list (priv->source_registry, source);
+}
+
 static void
 gtd_provider_eds_fill_task_list (GObject      *client,
                                  GAsyncResult *result,
@@ -266,6 +280,8 @@ gtd_provider_eds_remove_source (GtdProviderEds *provider,
   priv = gtd_provider_eds_get_instance_private (provider);
   list = g_object_get_data (G_OBJECT (source), "task-list");
 
+  priv->task_lists = g_list_remove (priv->task_lists, list);
+
   g_hash_table_remove (priv->clients, source);
 
   /* Since all subclasses will have this signal given that they
@@ -527,21 +543,28 @@ gtd_provider_eds_create_task_finished (GObject      *client,
 
   if (error)
     {
+      GtdTask *task = GTD_TASK (data->data);
+
       g_warning ("%s: %s: %s",
                  G_STRFUNC,
                  _("Error creating task"),
                  error->message);
 
+      /* Remove from the tasklist */
+      gtd_task_list_remove_task (gtd_task_get_list (task), task);
+
+      /* Display a notification */
       gtd_manager_emit_error_message (gtd_manager_get_default (),
                                       _("Error creating task"),
                                       error->message);
 
       g_error_free (error);
-      g_free (data);
-      return;
     }
   else
     {
+      /* Update the default tasklist */
+      gtd_provider_eds_set_default (data->provider, gtd_task_get_list (GTD_TASK (data->data)));
+
       /*
        * In the case the task UID changes because of creation proccess,
        * reapply it to the task.
@@ -551,9 +574,9 @@ gtd_provider_eds_create_task_finished (GObject      *client,
           gtd_object_set_uid (GTD_OBJECT (data->data), new_uid);
           g_free (new_uid);
         }
-
-      g_free (data);
     }
+
+  g_free (data);
 }
 
 static void
@@ -582,9 +605,9 @@ gtd_provider_eds_update_task_finished (GObject      *client,
       g_error_free (error);
     }
 
-  g_free (data);
-
   gtd_object_set_ready (GTD_OBJECT (data->data), TRUE);
+
+  g_free (data);
 }
 
 static void
@@ -1002,3 +1025,22 @@ gtd_provider_eds_get_task_lists (GtdProviderEds *provider)
 
   return priv->task_lists;
 }
+
+GtdTaskList*
+gtd_provider_eds_get_default_task_list (GtdProviderEds *provider)
+{
+  GtdProviderEdsPrivate *priv;
+  GtdTaskList *default_task_list;
+  ESource *default_source;
+
+  priv = gtd_provider_eds_get_instance_private (provider);
+  default_source = e_source_registry_ref_default_task_list (priv->source_registry);
+  default_task_list = g_object_get_data (G_OBJECT (default_source), "task-list");
+
+  g_clear_object (&default_source);
+
+  if (gtd_task_list_get_provider (default_task_list) != GTD_PROVIDER (provider))
+    return NULL;
+
+  return default_task_list;
+}
