@@ -13,6 +13,9 @@ G_BEGIN_DECLS
 #define GTD_TYPE_WINDOW_MODE	(gtd_window_mode_get_type())
 GType gtd_window_mode_get_type	(void) G_GNUC_CONST;
 
+#define GTD_TYPE_LIST_SELECTOR_VIEW_TYPE	(gtd_list_selector_view_type_get_type())
+GType gtd_list_selector_view_type_get_type	(void) G_GNUC_CONST;
+
 G_END_DECLS
 
 #endif /* __GTD_ENUMS_H__ */
