@@ -104,6 +104,8 @@ typedef struct
   /* Custom sorting function data */
   GtdTaskListViewSortFunc sort_func;
   gpointer                sort_user_data;
+
+  GtkWidget             *active_row;
 } GtdTaskListViewPrivate;
 
 struct _GtdTaskListView
@@ -163,6 +165,27 @@ enum {
 typedef gboolean     (*IterateSubtaskFunc)                       (GtdTaskListView    *self,
                                                                   GtdTask            *task);
 
+/*
+ * Active row management
+ */
+static void
+set_active_row (GtdTaskListView *self,
+                GtkWidget       *row)
+{
+  GtdTaskListViewPrivate *priv = gtd_task_list_view_get_instance_private (self);
+
+  if (priv->active_row == row)
+    return;
+
+  if (priv->active_row)
+    gtd_task_row_set_active (GTD_TASK_ROW (priv->active_row), FALSE);
+
+  priv->active_row = row;
+
+  if (row)
+    gtd_task_row_set_active (GTD_TASK_ROW (row), TRUE);
+}
+
 /*
  * Auxiliary function to iterate through a list of subtasks
  */
@@ -660,6 +683,9 @@ gtd_task_list_view__remove_task_cb (GtdEditPane *pane,
 
   gtd_window_notify (window, notification);
 
+  /* Clear the active row */
+  set_active_row (user_data, NULL);
+
   g_clear_pointer (&text, g_free);
 
 out:
@@ -679,6 +705,8 @@ gtd_task_list_view__edit_task_finished (GtdEditPane *pane,
 
   priv = GTD_TASK_LIST_VIEW (user_data)->priv;
 
+  set_active_row (user_data, NULL);
+
   gtk_revealer_set_reveal_child (priv->edit_revealer, FALSE);
 
   gtd_task_save (task);
@@ -800,6 +828,8 @@ task_row_entered_cb (GtdTaskListView *self,
 
   gtk_revealer_set_reveal_child (priv->edit_revealer, TRUE);
   gtd_arrow_frame_set_row (priv->arrow_frame, row);
+
+  set_active_row (self, GTK_WIDGET (row));
 }
 
 static void
@@ -822,6 +852,23 @@ task_row_exited_cb (GtdTaskListView *self,
 
   gtk_revealer_set_reveal_child (priv->edit_revealer, FALSE);
   gtd_arrow_frame_set_row (priv->arrow_frame, NULL);
+
+  if (GTK_WIDGET (row) == priv->active_row &&
+      priv->active_row != GTK_WIDGET (priv->new_task_row))
+    {
+      set_active_row (self, NULL);
+    }
+}
+
+static void
+listbox_row_activated (GtkListBox      *listbox,
+                       GtkListBox      *row,
+                       GtdTaskListView *self)
+{
+  if (!GTD_IS_TASK_ROW (row))
+    return;
+
+  set_active_row (self, GTK_WIDGET (row));
 }
 
 static void
@@ -864,6 +911,9 @@ destroy_task_row (GtdTaskListView *self,
   g_signal_handlers_disconnect_by_func (row, task_row_entered_cb, self);
   g_signal_handlers_disconnect_by_func (row, task_row_exited_cb, self);
 
+  if (GTK_WIDGET (row) == self->priv->active_row)
+    set_active_row (self, NULL);
+
   gtd_task_row_destroy (row);
 }
 
@@ -1576,6 +1626,7 @@ gtd_task_list_view_class_init (GtdTaskListViewClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, listbox_drag_drop);
   gtk_widget_class_bind_template_callback (widget_class, listbox_drag_leave);
   gtk_widget_class_bind_template_callback (widget_class, listbox_drag_motion);
+  gtk_widget_class_bind_template_callback (widget_class, listbox_row_activated);
   gtk_widget_class_bind_template_callback (widget_class, task_row_exited_cb);
 
   gtk_widget_class_set_css_name (widget_class, "task-list-view");
@@ -1590,6 +1641,8 @@ gtd_task_list_view_init (GtdTaskListView *self)
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
+  self->priv->active_row = GTK_WIDGET (self->priv->new_task_row);
+
   gtk_drag_dest_set (GTK_WIDGET (self->priv->listbox),
                      0,
                      NULL,
@@ -1753,76 +1806,83 @@ gtd_task_list_view_set_task_list (GtdTaskListView *view,
                                   GtdTaskList     *list)
 {
   GtdTaskListViewPrivate *priv = view->priv;
+  GdkRGBA *color;
+  gchar *color_str;
+  gchar *parsed_css;
+  GList *task_list;
 
   g_return_if_fail (GTD_IS_TASK_LIST_VIEW (view));
-  g_return_if_fail (GTD_IS_TASK_LIST (list));
 
-  if (priv->task_list != list)
+  if (priv->task_list == list)
+    return;
+
+  /*
+   * Disconnect the old GtdTaskList signals.
+   */
+  if (priv->task_list)
     {
-      GdkRGBA *color;
-      gchar *color_str;
-      gchar *parsed_css;
-      GList *task_list;
-
-      /*
-       * Disconnect the old GtdTaskList signals.
-       */
-      if (priv->task_list)
-        {
-          g_signal_handlers_disconnect_by_func (priv->task_list,
-                                                gtd_task_list_view__task_added,
-                                                view);
-          g_signal_handlers_disconnect_by_func (priv->task_list,
-                                                gtd_task_list_view__color_changed,
-                                                view);
-        }
-
-      /* Add the color to provider */
-      color = gtd_task_list_get_color (list);
-      color_str = gdk_rgba_to_string (color);
-
-      parsed_css = g_strdup_printf (COLOR_TEMPLATE, color_str);
-
-      g_debug ("setting style for provider: %s", parsed_css);
-
-      gtk_css_provider_load_from_data (priv->color_provider,
-                                       parsed_css,
-                                       -1,
-                                       NULL);
-
-      g_free (parsed_css);
-      gdk_rgba_free (color);
-      g_free (color_str);
-
-      /* Load task */
-      priv->task_list = list;
-
-      update_font_color (view);
-
-      /* Add the tasks from the list */
-      task_list = gtd_task_list_get_tasks (list);
-
-      gtd_task_list_view_set_list (view, task_list);
-
-      g_list_free (task_list);
-
-      g_signal_connect (list,
-                        "task-added",
-                        G_CALLBACK (gtd_task_list_view__task_added),
-                        view);
-      g_signal_connect_swapped (list,
-                                "task-removed",
-                                G_CALLBACK (gtd_task_list_view__remove_task),
-                                view);
-      g_signal_connect_swapped (list,
-                                "notify::color",
-                                G_CALLBACK (gtd_task_list_view__color_changed),
-                                view);
-      g_signal_connect_swapped (list,
-                                "task-updated",
-                                G_CALLBACK (gtk_list_box_invalidate_sort),
-                                priv->listbox);
+      g_signal_handlers_disconnect_by_func (priv->task_list,
+                                            gtd_task_list_view__task_added,
+                                            view);
+      g_signal_handlers_disconnect_by_func (priv->task_list,
+                                            gtd_task_list_view__color_changed,
+                                            view);
     }
+
+  priv->task_list = list;
+
+  if (!list)
+    {
+      gtd_edit_pane_set_task (GTD_EDIT_PANE (priv->edit_pane), NULL);
+      gtd_task_list_view_set_list (view, NULL);
+      return;
+    }
+
+  /* Add the color to provider */
+  color = gtd_task_list_get_color (list);
+  color_str = gdk_rgba_to_string (color);
+
+  parsed_css = g_strdup_printf (COLOR_TEMPLATE, color_str);
+
+  g_debug ("setting style for provider: %s", parsed_css);
+
+  gtk_css_provider_load_from_data (priv->color_provider,
+                                   parsed_css,
+                                   -1,
+                                   NULL);
+
+  g_free (parsed_css);
+  gdk_rgba_free (color);
+  g_free (color_str);
+
+  update_font_color (view);
+
+  /* Add the tasks from the list */
+  task_list = gtd_task_list_get_tasks (list);
+
+  gtd_task_list_view_set_list (view, task_list);
+  gtd_edit_pane_set_task (priv->edit_pane, NULL);
+
+  g_list_free (task_list);
+
+  g_signal_connect (list,
+                    "task-added",
+                    G_CALLBACK (gtd_task_list_view__task_added),
+                    view);
+  g_signal_connect_swapped (list,
+                            "task-removed",
+                            G_CALLBACK (gtd_task_list_view__remove_task),
+                            view);
+  g_signal_connect_swapped (list,
+                            "notify::color",
+                            G_CALLBACK (gtd_task_list_view__color_changed),
+                            view);
+  g_signal_connect_swapped (list,
+                            "task-updated",
+                            G_CALLBACK (gtk_list_box_invalidate_sort),
+                            priv->listbox);
+
+  set_active_row (view, GTK_WIDGET (priv->new_task_row));
 }
 
 /**
