@@ -19,6 +19,20 @@
 #include "gtd-provider.h"
 #include "gtd-task-list.h"
 
+/**
+ * SECTION:gtd-provider
+ * @short_description:data sources for GNOME To do
+ * @title: GtdProvider
+ * @stability:Unstable
+ *
+ * The #GtdProvider is the interface that GNOME To Do uses to
+ * connect to data sources. It must provide ways to create, update
+ * and remove tasks and tasklists.
+ *
+ * A provider implementation must also expose which is the default
+ * tasklist among the tasklists it manages.
+ */
+
 G_DEFINE_INTERFACE (GtdProvider, gtd_provider, GTD_TYPE_OBJECT)
 
 enum
@@ -334,6 +348,7 @@ gtd_provider_update_task_list (GtdProvider *provider,
 
   GTD_PROVIDER_GET_IFACE (provider)->update_task_list (provider, list);
 }
+
 /**
  * gtd_provider_remove_task_list:
  * @provider: a #GtdProvider
@@ -350,6 +365,7 @@ gtd_provider_remove_task_list (GtdProvider *provider,
 
   GTD_PROVIDER_GET_IFACE (provider)->remove_task_list (provider, list);
 }
+
 /**
  * gtd_provider_get_task_lists:
  * @provider: a #GtdProvider
@@ -366,3 +382,20 @@ gtd_provider_get_task_lists (GtdProvider *provider)
 
   return GTD_PROVIDER_GET_IFACE (provider)->get_task_lists (provider);
 }
+
+/**
+ * gtd_provider_get_default_task_list:
+ * @provider: a #GtdProvider
+ *
+ * Retrieves the default tasklist of @provider.
+ *
+ * Returns: (transfer none)(nullable): the default tasklist, or %NULL
+ */
+GtdTaskList*
+gtd_provider_get_default_task_list (GtdProvider *provider)
+{
+  g_return_val_if_fail (GTD_IS_PROVIDER (provider), NULL);
+  g_return_val_if_fail (GTD_PROVIDER_GET_IFACE (provider)->get_default_task_list, NULL);
+
+  return GTD_PROVIDER_GET_IFACE (provider)->get_default_task_list (provider);
+}
